# PrismNET - File and Directory Utility

PrismNET is a Python utility class designed to simplify common file and directory operations. It provides methods for creating, deleting, and checking the existence of files and directories, as well as generating random strings and numbers.

## Methods

### Create File
Creates a new file with the specified filename.

```python
PrismNET.create_file(filename)
```
```python
PrismNET.delete_file(filename)
```
```python
PrismNET.get_random_string(length)
```